@@ -108,7 +108,7 @@ def showEllipsoid(modes, onto=None, n_std=2, scale=1., *args, **kwargs):
             show = child
             break
     if show is None:
-        show = Axes3D(cf)
+        show = cf.add_subplot(projection="3d")
     show.plot_wireframe(x, y, z, rstride=6, cstride=6, *args, **kwargs)
     if onto is not None:
         onto = list(onto)
@@ -200,10 +200,11 @@ def showProjection(ensemble, modes, *args, **kwargs):
     :arg modes: up to three normal modes
     :type modes: :class:`.Mode`, :class:`.ModeSet`, :class:`.NMA`
 
-    :keyword by_time: whether to show a 1D projection by time (number of steps) 
-        on the x-axis, rather than making a population histogram. 
-        Default is **False** to maintain old behaviour.
-    :type by_time: bool
+    :keyword show_density: whether to show a density histogram or kernel density estimate
+        rather than a 2D scatter of points or a 1D projection by time (number of steps) 
+        on the x-axis. This option is not valid for 3D projections.
+        Default is **True** for 1D and **False** for 2D to maintain old behaviour.
+    :type show_density: bool
 
     :keyword color: a color name or a list of color names or values, 
         default is ``'blue'``
@@ -246,12 +247,13 @@ def showProjection(ensemble, modes, *args, **kwargs):
                                 kwargs.pop('norm', False))
 
     if projection.ndim == 1 or projection.shape[1] == 1:
-        by_time = kwargs.pop('by_time', False)
+        by_time = not kwargs.pop('show_density', True)
+        by_time = kwargs.pop('by_time', by_time)
         if by_time:
             show = plt.plot(range(len(projection)), projection.flatten(), *args, **kwargs)
             plt.ylabel('Mode {0} coordinate'.format(str(modes)))
             plt.xlabel('Conformation number')  
-        else:          
+        else:
             show = plt.hist(projection.flatten(), *args, **kwargs)
             plt.xlabel('Mode {0} coordinate'.format(str(modes)))
             plt.ylabel('Number of conformations')
@@ -299,6 +301,7 @@ def showProjection(ensemble, modes, *args, **kwargs):
     kwargs['linestyle'] = kwargs.pop('linestyle', None) or kwargs.pop('ls', 'None')
 
     texts = kwargs.pop('text', None)
+    adjust = kwargs.pop('adjust', True)
     if texts:
         if not isinstance(texts, list):
             raise TypeError('text must be a list')
@@ -311,12 +314,25 @@ def showProjection(ensemble, modes, *args, **kwargs):
         indict[opts].append(i)
 
     modes = [m for m in modes]
-    if len(modes) == 2: 
-        plot = plt.plot
+    if len(modes) == 2:
+        show_density = kwargs.pop("show_density", False)
+        if show_density:
+            try:
+                import seaborn as sns
+                plot = sns.kdeplot
+                kwargs["cmap"] = cmap
+            except ImportError:
+                raise ImportError('Please install seaborn to plot kernel density estimates')
+        else:
+            plot = plt.plot
         show = plt.gcf()
         text = plt.text
     else: 
         from mpl_toolkits.mplot3d import Axes3D
+        show_density = kwargs.pop("show_density", False)
+        if show_density:
+            LOGGER.warn("show_density is not supported yet for 3D projections")
+            show_density = False
         cf = plt.gcf()
         show = None
         for child in cf.get_children():
@@ -324,7 +340,7 @@ def showProjection(ensemble, modes, *args, **kwargs):
                 show = child
                 break
         if show is None:
-            show = Axes3D(cf)
+            show = cf.add_subplot(projection="3d")
         plot = show.plot
         text = show.text
 
@@ -344,7 +360,10 @@ def showProjection(ensemble, modes, *args, **kwargs):
         else:
             kwargs.pop('label', None)
 
-        plot(*(list(projection[indices].T) + args), **kwargs)
+        if not show_density:
+            plot(*(list(projection[indices].T) + args), **kwargs)
+        else:
+            plot(x=list(projection[indices,0]), y=list(projection[indices,1]), **kwargs)
 
     if texts:
         ts = []
@@ -359,7 +378,8 @@ def showProjection(ensemble, modes, *args, **kwargs):
         except ImportError:
             pass
         else:
-            adjust_text(ts)
+            if len(modes) == 2 and adjust == True:
+                adjust_text(ts)
 
     if len(modes) == 2:
         plt.xlabel('Mode {0} coordinate'.format(int(modes[0])+1))
@@ -1508,6 +1528,11 @@ def showAtomicMatrix(matrix, x_array=None, y_array=None, atoms=None, **kwargs):
     text_color = kwargs.pop('text_color', 'k')
     text_color = kwargs.pop('textcolor', text_color)
     interactive = kwargs.pop('interactive', True)
+    
+    import matplotlib
+    if float(matplotlib.__version__[:-2]) >= 3.6:
+        LOGGER.warn('matplotlib 3.6 and later are not compatible with interactive matrices')
+        interactive = False
 
     if isinstance(fig, Figure):
         fig_num = fig.number
