@@ -69,9 +69,14 @@ def parseMMCIF(pdb, **kwargs):
 
     :arg chain: comma separated string or list-like of chain IDs
     :type chain: str, tuple, list, :class:`~numpy.ndarray`
+
+    :arg unite_chains: unite chains with the same segment name
+        Default is *False*
+    :type unite_chains: bool
     """
     chain = kwargs.pop('chain', None)
     title = kwargs.get('title', None)
+    unite_chains = kwargs.get('unite_chains', False)
     auto_bonds = SETTINGS.get('auto_bonds')
     get_bonds = kwargs.get('bonds', auto_bonds)
     if get_bonds:
@@ -116,6 +121,8 @@ def parseMMCIF(pdb, **kwargs):
     cif = openFile(pdb, 'rt')
     result = parseMMCIFStream(cif, chain=chain, **kwargs)
     cif.close()
+    if unite_chains:
+        result.setSegnames(result.getChids())
     return result
 
 
@@ -252,6 +259,7 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
     fields = OrderedDict()
     fieldCounter = -1
     foundAtomBlock = False
+    foundAtomFields = False
     doneAtomBlock = False
     start = 0
     stop = 0
@@ -260,8 +268,9 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
         if line[:11] == '_atom_site.':
             fieldCounter += 1
             fields[line.split('.')[1].strip()] = fieldCounter
+            foundAtomFields = True
 
-        if line.startswith('ATOM ') or line.startswith('HETATM'):
+        elif foundAtomFields and line.strip() != '#':
             if not foundAtomBlock:
                 foundAtomBlock = True
                 start = i
@@ -269,10 +278,19 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
             if len(models) == 1 or (models[asize] != models[asize-1]):
                 nModels += 1
             asize += 1
+
         else:
             if foundAtomBlock:
                 doneAtomBlock = True
                 stop = i
+                
+        if i == len(lines) - 1:
+            if foundAtomBlock:
+                doneAtomBlock = True
+                stop = i
+            else:
+                raise MMCIFParseError('mmCIF file contained no atoms.')
+
         i += 1
 
     new_start = start
@@ -332,10 +350,26 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
     for line in lines[start:stop]:
         startswith = line.split()[fields['group_PDB']]
 
-        atomname = line.split()[fields['auth_atom_id']]
+        try:
+            atomname = line.split()[fields['auth_atom_id']]
+        except KeyError:
+            try:
+                atomname = line.split()[fields['label_atom_id']]
+            except KeyError:
+                raise MMCIFParseError('mmCIF file is missing required atom IDs.')
+ 
+
         if atomname.startswith('"') and atomname.endswith('"'):
             atomname = atomname[1:-1]
-        resname = line.split()[fields['auth_comp_id']]
+        
+        try:
+            resname = line.split()[fields['auth_comp_id']]
+        except KeyError:
+            try:
+                resname = line.split()[fields['label_comp_id']]
+            except KeyError:
+                raise MMCIFParseError('mmCIF file is missing required component IDs.')
+                
 
         if subset is not None:
             if not (atomname in subset and resname in protein_resnames):
@@ -362,11 +396,19 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
                                line.split()[fields['Cartn_z']]]
         atomnames[acount] = atomname
         resnames[acount] = resname
-        resnums[acount] = line.split()[fields['auth_seq_id']]
         chainids[acount] = chID
         segnames[acount] = segID
         hetero[acount] = startswith == 'HETATM' # True or False
 
+        try:
+            resnums[acount] = line.split()[fields['auth_seq_id']]
+        except KeyError:
+            try:
+                resnums[acount] = line.split()[fields['label_seq_id']]
+            except KeyError:
+                raise MMCIFParseError('mmCIF file is missing required sequence IDs.')
+
+
         if chainids[acount] != chainids[acount-1]: 
             termini[acount-1] = True
 
@@ -377,7 +419,7 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
         except KeyError:
             icodes[acount] = ''
 
-        if icodes[acount] == '?': 
+        if icodes[acount] == '?' or icodes[acount] == '.':
             icodes[acount] = ''
 
         serials[acount] = line.split()[fields['id']]
@@ -404,6 +446,7 @@ def _parseMMCIFLines(atomgroup, lines, model, chain, subset,
     atomgroup.setChids(chainids[:modelSize])
     atomgroup.setFlags('hetatm', hetero[:modelSize])
     atomgroup.setFlags('pdbter', termini[:modelSize])
+    atomgroup.setFlags('selpdbter', termini[:modelSize])
     atomgroup.setAltlocs(altlocs[:modelSize])
     atomgroup.setIcodes(icodes[:modelSize])
     atomgroup.setSerials(serials[:modelSize])
