@@ -16,8 +16,7 @@ from prody import LOGGER, SELECT, PY2K, PY3K
 from prody.sequence import MSA
 from prody.utilities import cmp, pystr, isListLike, multilap, SolutionDepletionException, index
 from prody.utilities import MATCH_SCORE, MISMATCH_SCORE, GAP_PENALTY, GAP_EXT_PENALTY, ALIGNMENT_METHOD
-
-from Bio import pairwise2
+from prody.utilities import alignBioPairwise
 
 if PY2K:
     range = xrange
@@ -562,7 +561,7 @@ def matchChains(atoms1, atoms2, **kwargs):
     This function tries to match chains based on residue numbers and names.
     All chains in *atoms1* is compared to all chains in *atoms2*.  This works
     well for different structures of the same protein.  When it fails,
-    :mod:`Bio.pairwise2` is used for pairwise sequence alignment, and matching
+    Biopython is used for pairwise sequence alignment, and matching
     is performed based on the sequence alignment.  User can control, whether
     sequence alignment is performed or not with *pwalign* keyword.  If
     ``pwalign=True`` is passed, pairwise alignment is enforced."""
@@ -649,30 +648,27 @@ def matchChains(atoms1, atoms2, **kwargs):
                     unmatched.append((simpch1, simpch2))
 
     if pwalign or (not matches and (pwalign is None or pwalign)):
-        if pairwise2:
-            if unmatched:
-                LOGGER.debug('Trying to match chains based on {0} sequence '
-                            'alignment:'.format(ALIGNMENT_METHOD))
-                for simpch1, simpch2 in unmatched:
-                    LOGGER.debug(' Comparing {0} (len={1}) and {2} '
-                                '(len={3}):'
-                                .format(simpch1.getTitle(), len(simpch1),
-                                        simpch2.getTitle(), len(simpch2)))
-                    match1, match2, nmatches = getAlignedMatch(simpch1, simpch2)
-                    _seqid = nmatches * 100 / min(len(simpch1), len(simpch2))
-                    _cover = len(match2) * 100 / max(len(simpch1), len(simpch2))
-                    if _seqid >= seqid and _cover >= coverage:
-                        LOGGER.debug('\tMatch: {0} residues match with {1:.0f}% '
-                                    'sequence identity and {2:.0f}% overlap.'
-                                    .format(len(match1), _seqid, _cover))
-                        matches.append((match1, match2, _seqid, _cover,
-                                        simpch1, simpch2))
-                    else:
-                        LOGGER.debug('\tFailed to match chains (seqid={0:.0f}%, '
-                                    'overlap={1:.0f}%).'
-                                    .format(_seqid, _cover))
-        else:
-            LOGGER.warning('Pairwise alignment could not be performed.')
+        if unmatched:
+            LOGGER.debug('Trying to match chains based on {0} sequence '
+                        'alignment:'.format(ALIGNMENT_METHOD))
+            for simpch1, simpch2 in unmatched:
+                LOGGER.debug(' Comparing {0} (len={1}) and {2} '
+                            '(len={3}):'
+                            .format(simpch1.getTitle(), len(simpch1),
+                                    simpch2.getTitle(), len(simpch2)))
+                match1, match2, nmatches = getAlignedMatch(simpch1, simpch2)
+                _seqid = nmatches * 100 / min(len(simpch1), len(simpch2))
+                _cover = len(match2) * 100 / max(len(simpch1), len(simpch2))
+                if _seqid >= seqid and _cover >= coverage:
+                    LOGGER.debug('\tMatch: {0} residues match with {1:.0f}% '
+                                'sequence identity and {2:.0f}% overlap.'
+                                .format(len(match1), _seqid, _cover))
+                    matches.append((match1, match2, _seqid, _cover,
+                                    simpch1, simpch2))
+                else:
+                    LOGGER.debug('\tFailed to match chains (seqid={0:.0f}%, '
+                                'overlap={1:.0f}%).'
+                                .format(_seqid, _cover))
     if not matches:
         return None
     subset = _SUBSETS[subset]
@@ -781,17 +777,19 @@ def getAlignedMatch(ach, bch):
     """
 
     if ALIGNMENT_METHOD == 'local':
-        alignment = pairwise2.align.localms(ach.getSequence(),
-                                            bch.getSequence(),
-                                            MATCH_SCORE, MISMATCH_SCORE,
-                                            GAP_PENALTY, GAP_EXT_PENALTY,
-                                            one_alignment_only=1)
+        alignment = alignBioPairwise(ach.getSequence(),
+                                     bch.getSequence(),
+                                     "local",
+                                     MATCH_SCORE, MISMATCH_SCORE,
+                                     GAP_PENALTY, GAP_EXT_PENALTY,
+                                     max_alignments=1)
     else:
-        alignment = pairwise2.align.globalms(ach.getSequence(),
-                                             bch.getSequence(),
-                                             MATCH_SCORE, MISMATCH_SCORE,
-                                             GAP_PENALTY, GAP_EXT_PENALTY,
-                                             one_alignment_only=1)
+        alignment = alignBioPairwise(ach.getSequence(),
+                                     bch.getSequence(),
+                                     "global",
+                                     MATCH_SCORE, MISMATCH_SCORE,
+                                     GAP_PENALTY, GAP_EXT_PENALTY,
+                                     max_alignments=1)
 
     amatch = []
     bmatch = []
@@ -925,12 +923,12 @@ def mapChainOntoChain(mobile, target, **kwargs):
     :type overlap: float
 
     :keyword mapping: what method will be used if the trivial mapping based on residue numbers 
-        fails. If ``"ce"`` or ``"cealign"``, then the CE algorithm [IS98]_ will be 
+        fails. If ``"ce"`` or ``"cealign"``, then the CE structural alignment [IS98]_ will be
         performed. It can also be a list of prealigned sequences, a :class:`.MSA` instance,
         or a dict of indices such as that derived from a :class:`.DaliRecord`.
-        If set to **True** then the sequence alignment from :mod:`~Bio.pairwise2` 
+        If set to **True** then the sequence alignment from Biopython 
         will be used. If set to **False**, only the trivial mapping will be performed. 
-        Default is **"auto"**
+        Default is **"auto"**, which means try sequence alignment then CE.
     :type mapping: list, str, bool
 
     :keyword pwalign: if **True**, then pairwise sequence alignment will 
@@ -1339,17 +1337,19 @@ def getAlignedMapping(target, chain, alignment=None):
 
     if alignment is None:
         if ALIGNMENT_METHOD == 'local':
-            alignments = pairwise2.align.localms(target.getSequence(),
-                                                chain.getSequence(),
-                                                MATCH_SCORE, MISMATCH_SCORE,
-                                                GAP_PENALTY,  GAP_EXT_PENALTY,
-                                                one_alignment_only=1)
+            alignments = alignBioPairwise(target.getSequence(),
+                                          chain.getSequence(),
+                                          "local",
+                                          MATCH_SCORE, MISMATCH_SCORE,
+                                          GAP_PENALTY,  GAP_EXT_PENALTY,
+                                          max_alignments=1)
         else:
-            alignments = pairwise2.align.globalms(target.getSequence(),
-                                                chain.getSequence(),
-                                                MATCH_SCORE, MISMATCH_SCORE,
-                                                GAP_PENALTY, GAP_EXT_PENALTY,
-                                                one_alignment_only=1)
+            alignments = alignBioPairwise(target.getSequence(),
+                                          chain.getSequence(),
+                                          "global",
+                                          MATCH_SCORE, MISMATCH_SCORE,
+                                          GAP_PENALTY, GAP_EXT_PENALTY,
+                                          max_alignments=1)
         alignment = alignments[0]
         this, that = alignment[:2]
     else:
