@@ -11,7 +11,7 @@ from numbers import Integral
 import numpy as np
 
 from prody.atomic import AtomGroup, Atom, Selection
-from prody.atomic import flags
+from prody.atomic import flags, AAMAP
 from prody.atomic import ATOMIC_FIELDS
 from prody.utilities import openFile, isListLike
 from prody.utilities.misctools import decToHybrid36, hybrid36ToDec, packmolRenumChains
@@ -841,6 +841,7 @@ def _parsePDBLines(atomgroup, lines, split, model, chain, subset,
                 atomgroup.setChids(chainids)
                 atomgroup.setFlags('hetatm', hetero)
                 atomgroup.setFlags('pdbter', termini)
+                atomgroup.setFlags('selpdbter', termini)
                 atomgroup.setAltlocs(altlocs)
                 atomgroup.setIcodes(np.char.strip(icodes))
                 atomgroup.setSerials(serials)
@@ -952,6 +953,7 @@ def _parsePDBLines(atomgroup, lines, split, model, chain, subset,
         atomgroup.setChids(chainids)
         atomgroup.setFlags('hetatm', hetero)
         atomgroup.setFlags('pdbter', termini)
+        atomgroup.setFlags('selpdbter', termini)
         atomgroup.setAltlocs(altlocs)
         atomgroup.setIcodes(np.char.strip(icodes))
         atomgroup.setSerials(serials)
@@ -1055,13 +1057,13 @@ def _evalAltlocs(atomgroup, altloc, chainids, resnums, resnames, atomnames):
 #             '                               %5d\n')
 
 HELIXLINE = ('HELIX  {serNum:3d} {helixID:>3s} '
-             '{initResName:<3s} {initChainID:1s} {initSeqNum:4d}{initICode:1s} '
-             '{endResName:<3s} {endChainID:1s} {endSeqNum:4d}{endICode:1s}'
-             '{helixClass:2d}                               {length:5d}\n')
+             '{initResName:<3s}{initChainID:>2s} {initSeqNum:4d}{initICode:1s} '
+             '{endResName:<3s}{endChainID:>2s} {endSeqNum:4d}{endICode:1s}'
+             '{helixClass:2d}                               {length:5d}    \n')
 
 SHEETLINE = ('SHEET  {strand:3d} {sheetID:>3s}{numStrands:2d} '
-             '{initResName:3s} {initChainID:1s}{initSeqNum:4d}{initICode:1s} '
-             '{endResName:3s} {endChainID:1s}{endSeqNum:4d}{endICode:1s}{sense:2d} \n')
+             '{initResName:3s}{initChainID:>2s}{initSeqNum:4d}{initICode:1s} '
+             '{endResName:3s}{endChainID:>2s}{endSeqNum:4d}{endICode:1s}{sense:2d} \n')
 
 PDBLINE_LT100K = ('%-6s%5d %-4s%1s%-3s%2s%4d%1s   '
                   '%8.3f%8.3f%8.3f%6.2f%6.2f      '
@@ -1195,6 +1197,11 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
     :arg renumber: whether to renumber atoms with serial indices
         Default is **True**
     :type renumber: bool
+
+    :arg hybrid36: whether to use hybrid36 format for atom residue numbers
+        Default is **False**, which means using hexadecimal instead.
+        NB: ChimeraX seems to prefer hybrid36 and may have problems with hexadecimal.
+    :type hybrid36: bool
     """
 
     renumber = kwargs.get('renumber', True)
@@ -1366,7 +1373,9 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
         torf_all_sheets = isSheet(secstrs)
         sheet_secids = secids[torf_all_sheets]
 
-        for sheet_id in np.unique(sheet_secids):
+        unique_sheet_secids, indices = np.unique(sheet_secids, return_index=True)
+        unique_sheet_secids = unique_sheet_secids[indices.argsort()]
+        for sheet_id in unique_sheet_secids:
             torf_strands_in_sheet = np.logical_and(torf_all_sheets, secids==sheet_id)
             strand_indices = secindices[torf_strands_in_sheet]
             numStrands = len(np.unique(strand_indices))
@@ -1390,6 +1399,7 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
     # write atoms
     multi = len(coordsets) > 1
     write = stream.write
+    num_ter_lines = 0
     for m, coords in enumerate(coordsets):
         if multi:
             write('MODEL{0:9d}\n'.format(m+1))
@@ -1407,6 +1417,9 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
         warned_5_digit = False
 
         for i, xyz in enumerate(coords):
+
+            serial = serials[i] + num_ter_lines
+
             if hybrid36:
                 pdbline = PDBLINE_H36
                 anisouline = ANISOULINE_H36
@@ -1416,7 +1429,7 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
                     warned_hybrid36 = True
 
             else:
-                if not (reached_max_n_atom or reached_max_n_res) and (i == MAX_N_ATOM or serials[i] > MAX_N_ATOM):
+                if not (reached_max_n_atom or reached_max_n_res) and (i == MAX_N_ATOM or serial > MAX_N_ATOM):
                     reached_max_n_atom = True
                     pdbline = PDBLINE_GE100K
                     anisouline = ANISOULINE_GE100K
@@ -1434,17 +1447,17 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
                     anisouline = ANISOULINE_GE100K_GE10K
                     LOGGER.warn('Resnums are exceeding 9999 and hexadecimal format is being used for indices and resnums')
 
-                elif reached_max_n_res and not reached_max_n_atom and (i == MAX_N_ATOM or serials[i] > MAX_N_ATOM):
+                elif reached_max_n_res and not reached_max_n_atom and (i == MAX_N_ATOM or serial > MAX_N_ATOM):
                     reached_max_n_atom = True
                     pdbline = PDBLINE_GE100K_GE10K
                     anisouline = ANISOULINE_GE100K_GE10K
                     LOGGER.warn('Indices are exceeding 99999 and hexadecimal format is being used for indices and resnums')
 
             if hybrid36:
-                serial = decToHybrid36(serials[i])
+                serial = decToHybrid36(serial)
                 resnum = decToHybrid36(resnums[i], resnum=True)
             else:
-                serial = serials[i]
+                serial = serial
                 resnum = resnums[i]
 
             if pdbline == PDBLINE_LT100K or hybrid36:
@@ -1511,12 +1524,44 @@ def writePDBStream(stream, atoms, csets=None, **kwargs):
                                     anisou[3], anisou[4], anisou[5],
                                     segments[i], elements[i], charges2[i]))
 
-            if atoms.getFlags('pdbter') is not None and atoms.getFlags('pdbter')[i]:
-                write('TER\n')
+            if isinstance(atoms, AtomGroup):
+                if resnames[i] in AAMAP and atoms._getFlags('pdbter') is not None and atoms.getFlags('pdbter')[i]:
+                    if hybrid36:
+                        serial = decToHybrid36(hybrid36ToDec(serial) + 1)
+                    else:
+                        serial += 1
+
+                    false_pdbline = pdbline % ("TER   ", serial,
+                                               "", "",
+                                               resnames[i], chainids[i], resnum,
+                                               icodes[i],
+                                               xyz[0], xyz[1], xyz[2],
+                                               occupancies[i], bfactors[i],
+                                               segments[i], elements[i], charges2[i])
+                    write(false_pdbline[:26] + " "*54 + '\n')
+                    num_ter_lines += 1
+            else:
+                if resnames[i] in AAMAP and atoms._getFlags('selpdbter') is not None and atoms.getFlags('selpdbter')[i]:
+                    if hybrid36:
+                        serial = decToHybrid36(hybrid36ToDec(serial) + 1)
+                    else:
+                        serial += 1
+
+                    false_pdbline = pdbline % ("TER   ", serial,
+                                               "", "",
+                                               resnames[i], chainids[i], resnum,
+                                               icodes[i],
+                                               xyz[0], xyz[1], xyz[2],
+                                               occupancies[i], bfactors[i],
+                                               segments[i], elements[i], charges2[i])
+                    write(false_pdbline[:26] + " "*54 + '\n')
+                    num_ter_lines += 1
 
         if multi:
-            write('ENDMDL\n')
+            write('ENDMDL' + " "*74 + '\n')
             altlocs = np.zeros(n_atoms, s_or_u + '1')
+            
+    write('END   ' + " "*74 + '\n')
 
 writePDBStream.__doc__ += _writePDBdoc
 
@@ -1528,10 +1573,15 @@ def writePDB(filename, atoms, csets=None, autoext=True, **kwargs):
     :arg renumber: whether to renumber atoms with serial indices
         Default is **True**
     :type renumber: bool
+
+    :arg hybrid36: whether to use hybrid36 format for atom residue numbers
+        Default is **False**, which means using hexadecimal instead.
+        NB: ChimeraX seems to prefer hybrid36 and may have problems with hexadecimal.
+    :type hybrid36: bool
     """
 
-    if not (filename.endswith('.pdb') or filename.endswith('.pdb.gz') or
-            filename.endswith('.ent') or filename.endswith('.ent.gz')):
+    if not (filename.lower().endswith('.pdb') or filename.lower().endswith('.pdb.gz') or
+            filename.lower().endswith('.ent') or filename.lower().endswith('.ent.gz')):
         filename += '.pdb'
     out = openFile(filename, 'wt')
     writePDBStream(out, atoms, csets, **kwargs)
@@ -1604,21 +1654,20 @@ def writePQRStream(stream, atoms, **kwargs):
         write(format_helix(*line))
 
 
-    sorted_sheet = sorted(sheet, key=lambda item: (item[2], item[1]))
     sheet_prev = 'A'
     num_strands_list = []
-    for i, item1 in enumerate(sorted_sheet):
+    for i, item1 in enumerate(sheet):
         if item1[2] != sheet_prev:
-            num_strands = sorted_sheet[i-1][1]
+            num_strands = sheet[i-1][1]
             num_strands_list.append(num_strands)
 
             sheet_prev = item1[2]
 
-            for item2 in sorted_sheet[i-num_strands:i]:
+            for item2 in sheet[i-num_strands:i]:
                 item2.append(num_strands)
 
-    num_strands = item1[1]
-    for item2 in sorted_sheet[i-num_strands+1:]:
+    num_strands = len(num_strands_list)
+    for item2 in sheet[i-num_strands+1:]:
         item2.append(num_strands)
 
     format_sheet = ('{0:6s} {1:3d} {2:3s}{12:2d} ' +
@@ -1626,7 +1675,7 @@ def writePQRStream(stream, atoms, **kwargs):
                     '{7:3s} {8:1s}{9:4d}{10:1s}' +
                     '{11:2d}\n').format
 
-    for i, line in enumerate(sorted_sheet):
+    for i, line in enumerate(sheet):
         write(format_sheet(*line))
 
     resnames = atoms._getResnames()
