@@ -10,7 +10,8 @@ from .logger import LOGGER
 
 __all__ = ['calcTree', 'clusterMatrix', 'showLines', 'showMatrix', 
            'reorderMatrix', 'findSubgroups', 'getCoords',  
-           'getLinkage', 'getTreeFromLinkage', 'clusterSubfamilies']
+           'getLinkage', 'getTreeFromLinkage', 'clusterSubfamilies', 
+           'calcRMSDclusters', 'calcGromosClusters', 'calcGromacsClusters']
 
 class LinkageError(Exception):
     pass
@@ -144,7 +145,12 @@ def clusterSubfamilies(similarities, n_clusters=0, linkage='all', method='tsne',
     return best_labels
 
 def getCoords(data):
+    """Get coordinates from *data* if possible and handle errors well.
 
+    :arg data: a coordinate set or an object with ``getCoords`` method
+    :type data: :class:`numpy.ndarray`, :class:`Atomic`, 
+        :class:`Ensemble`, :class:`Trajectory`
+    """
     try:
         data = (data._getCoords() if hasattr(data, '_getCoords') else
                 data.getCoords())
@@ -601,7 +607,10 @@ def showLines(*args, **kwargs):
     return lines, polys
 
 def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
-    """Show a matrix using :meth:`~matplotlib.axes.Axes.imshow`. Curves on x- and y-axis can be added.
+    """Show a matrix using :meth:`~matplotlib.axes.Axes.imshow` or
+    :meth:`~matplotlib.axes.Axes.scatter` if *markersize* is provided.
+
+    Curves on x- and y-axis can be added.
 
     :arg matrix: matrix to be displayed
     :type matrix: :class:`~numpy.ndarray`
@@ -622,6 +631,12 @@ def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
     :arg xtickrotation: how much to rotate the xticklabels in degrees
                         default is 0
     :type xtickrotation: float
+
+    :arg markersize: size of square markers for using :meth:`~matplotlib.axes.Axes.scatter`
+        to help show matrices with small data regions compared to zeros.
+        Note only non-zeros are plotted so the colorbar range may change if not using norm
+        Default is None, which results in using :meth:`~matplotlib.axes.Axes.imshow`
+    :type markersize: float
     """
 
     from matplotlib import ticker
@@ -642,6 +657,8 @@ def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
     vcenter = kwargs.pop('vcenter', None)
     norm = kwargs.pop('norm', None)
 
+    markersize = kwargs.pop('markersize', None)
+
     if vcenter is not None and norm is None:
         if PY3K:
             try:
@@ -649,7 +666,7 @@ def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
             except ImportError:
                 from matplotlib.colors import TwoSlopeNorm as DivergingNorm
 
-            norm = DivergingNorm(vmin=vmin, vcenter=0., vmax=vmax)
+            norm = DivergingNorm(vmin=vmin, vcenter=vcenter, vmax=vmax)
         else:
             LOGGER.warn('vcenter cannot be used in Python 2 so norm remains None')
 
@@ -668,17 +685,26 @@ def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
     allticks = kwargs.pop('allticks', False) # this argument is temporary and will be replaced by better implementation
     interactive = kwargs.pop('interactive', True)
 
+    import matplotlib
+    if float(matplotlib.__version__[:-2]) >= 3.6:
+        LOGGER.warn('matplotlib 3.6 and later are not compatible with interactive matrices')
+        interactive = False
+
     cmap = kwargs.pop('cmap', 'jet')
     origin = kwargs.pop('origin', 'lower')
 
-    try: 
-        from Bio import Phylo
-    except ImportError:
-        raise ImportError('Phylo module could not be imported. '
-            'Reinstall ProDy or install Biopython '
-            'to solve the problem.')
-    tree_mode_y = isinstance(y_array, Phylo.BaseTree.Tree)
-    tree_mode_x = isinstance(x_array, Phylo.BaseTree.Tree)
+    if not isinstance(x_array, np.ndarray) or not isinstance(y_array, np.ndarray):
+        try:
+            from Bio import Phylo
+        except ImportError:
+            raise ImportError('Phylo module could not be imported. '
+                'Reinstall ProDy or install Biopython '
+                'to solve the problem.')
+        tree_mode_y = isinstance(y_array, Phylo.BaseTree.Tree)
+        tree_mode_x = isinstance(x_array, Phylo.BaseTree.Tree)
+    else:
+        tree_mode_x = False
+        tree_mode_y = False
 
     if x_array is not None and y_array is not None:
         nrow = 2; ncol = 2
@@ -723,11 +749,18 @@ def showMatrix(matrix, x_array=None, y_array=None, **kwargs):
     else:
         ax3 = gca()
     
-    im = ax3.imshow(matrix, aspect=aspect, vmin=vmin, vmax=vmax, 
-                    norm=norm, cmap=cmap, origin=origin, **kwargs)
-                    
-    #ax3.set_xlim([-0.5, matrix.shape[0]+0.5])
-    #ax3.set_ylim([-0.5, matrix.shape[1]+0.5])
+    if markersize is None:
+        # default behaviour
+        im = ax3.imshow(matrix, aspect=aspect, vmin=vmin, vmax=vmax,
+                        norm=norm, cmap=cmap, origin=origin, **kwargs)
+    else:
+        plot_list = []
+        for rows,cols in zip(np.where(matrix!=0)[0],np.where(matrix!=0)[1]):
+            plot_list.append([cols,rows,matrix[rows,cols]])
+        plot_list = np.array(plot_list)
+
+        im = ax3.scatter(plot_list[:,0], plot_list[:,1], c=plot_list[:,2],
+                         s=markersize, marker='s', cmap=cmap, norm=norm, **kwargs)
 
     if xticklabels is not None:
         ax3.xaxis.set_major_formatter(IndexFormatter(xticklabels))
@@ -968,3 +1001,50 @@ def findSubgroups(tree, c, method='naive', **kwargs):
             subgroups[t-1].append(names[i])
 
     return subgroups
+
+
+def calcRMSDclusters(rmsd_matrix, c, labels=None):
+    """
+    Divide **rmsd_matrix** into clusters using the gromos method 
+    with a cutoff **c** as implemented in gromacs (see 
+    https://manual.gromacs.org/documentation/current/onlinehelp/gmx-cluster.html)
+
+    Returns a list of lists with labels divided into clusters.
+    """    
+    clusters = []
+
+    useful_rmsd_matrix = rmsd_matrix
+    indices = list(range(len(rmsd_matrix)))
+    if labels is None:
+        elements = indices
+    else:
+        elements = labels
+
+    while len(elements) > 0:
+        neighbours = []
+        num_neighbours = np.zeros(len(elements))
+        for i, elem in enumerate(elements):
+            neighbours_i = list(np.array(elements)[list(np.where(useful_rmsd_matrix[i] <= c)[0])])
+            neighbours_i.pop(neighbours_i.index(elem))
+            neighbours.append(neighbours_i)
+            num_neighbours[i] = len(neighbours_i)
+
+        argmax_num_n = np.argmax(num_neighbours)
+        argmax_elem = elements[argmax_num_n]
+
+        clusters.append([])
+        for i, elem in enumerate(elements):
+            if argmax_elem in neighbours[i] or elem == argmax_elem:
+                clusters[-1].append(elem)
+
+                elements = list(elements)
+                indices.pop(elements.index(elem))
+                elements.pop(elements.index(elem))
+                elements = np.array(elements)
+
+        useful_rmsd_matrix = rmsd_matrix[:, list(indices)][list(indices), :]
+
+    return clusters
+
+calcGromosClusters = calcRMSDclusters
+calcGromacsClusters = calcRMSDclusters
